{% if top_errors %}
    <div class="alert alert-error">
        <a class="close" data-dismiss="alert">&times;</a>
        {{ top_errors }}
    </div>
{% endif %}

{{ hidden_fields }}

{% block rows %}
    {{ rows }}
{% endblock %}
