<div class="control-group{% if errors %} error{% endif %}{% if css_classes %} {{ css_classes }}{% endif %}" id="row-{{ name }}">
    {% block label %}
        <div class="control-label">{{ label }}</div>
    {% endblock %}

    <div class="controls">
        {% block field %}{{ field }}{% endblock %}

        {% for error in errors %}
            <span class="help-inline">{{ error }}</span>
        {% endfor %}

        {% if help_text %}
            <p class="help-block">
                {{ help_text }}
            </p>
        {% endif %}
    </div>
</div>
